@@ -6,14 +6,14 @@ tree.age_table<-function(tree){
     tree_length <- Ntip(tree)
     
     ages <- castor::get_all_pairwise_distances(tree)[tree_length + 1,]
-    tip.names <- tree$tip.label
+    tip.names <- tree$tip.label[1:tree_length]
     if(is.null(tree$node.label)) {
         nod.names <- c((tree_length + 1):length(castor::get_all_pairwise_distances(tree)[, 1]))
     } else {
-        nod.names <- tree$node.label
+        nod.names <- tree$node.label[1:Nnode(tree)]
     }
     elements <- c(tip.names, nod.names)
-    ages.table <- data.frame(ages = ages,elements = elements)
+    ages.table <- data.frame(ages = ages, elements = elements)
     return(ages.table)
 }
 
